Package: HH
Type: Package
Title: Statistical Analysis and Data Display: Heiberger and Holland
Version: 3.1-53
Date: 2025-02-05
Author: Richard M. Heiberger [aut, cre]
Maintainer: Richard M. Heiberger <rmh@temple.edu>
Depends: R (>= 3.0.2), lattice, stats, grid, latticeExtra, multcomp,
        gridExtra (>= 2.0.0), graphics
Imports: reshape2, leaps, vcd, colorspace, RColorBrewer, shiny (>=
        0.13.1), Hmisc, abind, Rmpfr (>= 0.6.0), grDevices, methods
Suggests: mvtnorm, car, Rcmdr, RcmdrPlugin.HH, microplot, MASS
Description: Support software for Statistical Analysis and Data Display (Second Edition, Springer, ISBN 978-1-4939-2121-8, 2015) and (First Edition, Springer, ISBN 0-387-40270-5, 2004) by Richard M. Heiberger and Burt Holland.  This contemporary presentation of statistical methods features extensive use of graphical displays for exploring data and for displaying the analysis.  The second edition includes redesigned graphics and additional chapters. The authors emphasize how to construct and interpret graphs, discuss principles of graphical design, and show how accompanying traditional tabular results are used to confirm the visual impressions derived directly from the graphs. Many of the graphical formats are novel and appear here for the first time in print.  All chapters have exercises.  All functions introduced in the book are in the package.  R code for all examples, both graphs and tables, in the book is included in the scripts directory of the package.
License: GPL (>= 2)
Authors@R: person(given = c("Richard", "M."),
                    family = "Heiberger",
                    role = c("aut", "cre"),
                    email = "rmh@temple.edu")
NeedsCompilation: no
Packaged: 2025-02-07 04:18:43 UTC; rmh
Repository: CRAN
Date/Publication: 2025-02-08 05:40:02 UTC
Built: R 4.6.0; ; 2026-04-29 10:24:38 UTC; unix
