hstr
====
BASH History Suggest Box.

[![BASH History Suggest Box](http://mindforger.com/projects/images/hh-3.png "BASH History Suggest Box @ YouTube")](http://www.youtube.com/watch?v=sPF29NyXe2U)


DESCRIPTION
-----------
Are you looking for a command that you used **recently**? Do you
want to  avoid the need to write **long commands** over and over
again despite you used them recently? Are you looking
for a tool that is able to manage your **favorite** commands?

HSTR is a command line utility that brings improved BASH command completion 
from the history. It aims to make completion **easier** and more **efficient**
than `Ctrl-r`.

Apart to the completion, history can be **managed** (you can remove 
commands that e.g. contain sensitive information like
passwords) and bookmark your favorite commands.

Enjoy [video](http://www.youtube.com/watch?v=sPF29NyXe2U) tutorial.


INSTALLATION
------------
Install `hh` using [distribution](INSTALLATION.md#distribution-installation), from [source code](INSTALLATION.md#installation-from-source-code), 
on [Ubuntu](INSTALLATION.md#ubuntu), [Debian/Mint](INSTALLATION.md#debianmint), [Arch Linux](INSTALLATION.md#arch-linux) 
or [Mac OS](INSTALLATION.md#mac-os).  


CONFIGURATION
-------------
Optionally configure `hh` just by running:
```bash
hh --show-configuration >> ~/.bashrc
```
For detailed `hh` configuration documentation please refer to [Configuration](CONFIGURATION.md).


DOCUMENTATION
-------------
Check `hh` man page:
```bash
man hh
```


BUGS
----
https://github.com/dvorka/hstr/issues
