This example shows the US population over time from 1900 to 1970 on an annual basis.
The population pyramid is rendered using the HH `likert` function.  The *Year* slider can
be used either to select a year manually, or to auomatically cycle through the years.
The data is from data(USAge.table) in the `latticeExtra` package.

Look for the visible effects of the First World War, the Second World War, and the Baby Boom.
