hstr
====
[![Current release](https://img.shields.io/github/release/dvorka/hstr.svg)](https://github.com/dvorka/hstr/releases)
[![GitHub issues](https://img.shields.io/github/issues/dvorka/hstr.svg?maxAge=360)](https://github.com/dvorka/hstr/issues)
[![All releases downloads](https://img.shields.io/github/downloads/dvorka/hstr/total.svg)](https://github.com/dvorka/hstr/releases)

Easily view, navigate and search your **command history** with shell history suggest box for Bash and
[Zsh](CONFIGURATION.md#zsh-history-settings).

[![Shell History Suggest Box](http://me.mindforger.com/projects/images/hh-animated-01.gif "Shell History Suggest Box @ YouTube")](http://www.youtube.com/watch?v=sPF29NyXe2U)


DESCRIPTION
-----------
Are you looking for a command that you used **recently**? Do you
want to  avoid the need to write **long commands** over and over
again? Are you looking for a tool that is able to manage your 
**favorite** commands?

HSTR is a command line utility that brings improved Bash command completion
from the history. It aims to make completion **easier** and more **efficient**
than <kbd>Ctrl-r</kbd>.

HSTR can also **manage** your command history (for instance you can remove
commands that are obsolete or contain a sensitive information) or **bookmark** 
your favorite commands.

Check [video](http://www.youtube.com/watch?v=sPF29NyXe2U) tutorial.


INSTALLATION
------------
Install HSTR:
* download [distribution](INSTALLATION.md#distribution-installation)
* build from [source code](INSTALLATION.md#installation-from-source-code)
* [Ubuntu](INSTALLATION.md#ubuntu)
* [Fedora](INSTALLATION.md#fedorarhelcentos)
* [Gentoo](INSTALLATION.md#gentoo)
* [CentOS](INSTALLATION.md#fedorarhelcentos)
* [openSUSE](INSTALLATION.md#opensuse)
* [RHEL](INSTALLATION.md#fedorarhelcentos)
* [Debian](INSTALLATION.md#debianmint)
* [Mint](INSTALLATION.md#debianmint)
* [Arch Linux](INSTALLATION.md#arch-linux)
* [Scientific Linux](INSTALLATION.md#fedorarhelcentos)
* [Bash on Ubuntu on Windows (WSL)](INSTALLATION.md#wsl)
* [Cygwin on Windows](INSTALLATION.md#cygwin)
* [Mac OS](INSTALLATION.md#mac-os)


CONFIGURATION
-------------
Optionally configure HSTR just by running:
```bash
hh --show-configuration >> ~/.bashrc
```
For detailed `hh` configuration documentation please refer to [Configuration](CONFIGURATION.md).


DOCUMENTATION
-------------
Check `hh` man page:
```bash
man hh
```

IN THE NEWS
-----------
Read about `hh` in [LinuxMagazine](http://www.linux-magazine.com/Issues/2014/164/Bash-History-on-Steroids), [UbuntuGeek](http://www.ubuntugeek.com/tag/hstr-bash-history), [DebianAdmin](http://www.debianadmin.com/hstr-easily-view-navigate-search-and-use-your-command-history-with-shell-history.html), [Tuxdiary](https://tuxdiary.com/2015/02/17/hstr/) or [Softpedia](http://linux.softpedia.com/get/Terminals/BASH-Command-History-Completion-103155.shtml).


BUGS
----
https://github.com/dvorka/hstr/issues
