# Examples

This directory contains usage examples for the Hospital Helpers library.

## Basic Usage

```rust
// See examples/basic.rs
cargo run --example basic
```

## Web API

```rust
// Start the web server
cargo run --bin hh-server
```
