## These files construct all the figures in the paper
##
## Heiberger, Richard M. and Holland, Burt (2006).
## "Mean--Mean Multiple Comparison Displays for Families of
## Linear Contrasts."
## Journal of Computational and Graphical Statistics.
## 2006, vol. 15, no. 4, pp. 937--955 


## All files work with S-Plus.
## All files except MMC.WoodEnergy.s.R work with R.
## All graphs in the WoodEnergy example can be drawn in both S-Plus and R.

## MMC.pulmonary.R and MMC.apple.R show tiebreaker plots.
